
file_id = "REGISTER_ACTIVITY"

--[[

REGISTER_ACTIVITY スクリプト起動時に渡されるパラメータ
---------------------------------------------------------------------------------
キー値				値		           									値の例
---------------------------------------------------------------------------------
RemoteDeviceName	監視用リモートデバイス名							LivingRoom

SerialNumber		監視用リモートデバイスのシリアル番号				0013A200404AC397

ActivityLevel		赤外センサーで関知した動作レベル(カウンタ値)		120

TemperatureLevel		温度センサーの値を A/D 変換した値					35
---------------------------------------------------------------------------------

カウンタ値　   統計用データベースキー名		"SENSOR_IR_" + <SerialNumber>
温度センサAD値 統計用データベースキー名		"SENSOR_TP_" + <SerialNumber>

統計用データベースに登録する値			ActivityLevel を数値に変換した値

]]

local temperature
local key,val,stat
local adc_vref


------------------------------------------------------------
-- 最初のデータ登録時に１回だけ、
-- A/D リファレンス電圧をデータベースに登録する
------------------------------------------------------------
stat,val = get_shared_data("AVREF_SETUP")
if not stat then error() end
if val == "" then
	if not inc_shared_data("AVREF_SETUP") then error() end

	if not script_exec("HOMESENSOR/AVREF_SETUP","","") then error() end
end

------------------------------------------------------------
-- A/D リファレンス電圧値取得
------------------------------------------------------------
stat,val = get_permanent_data("AVref_" .. g_params["RemoteDeviceName"])
if not stat then
	log_msg("*ERROR* adc_vref read error",file_id)
	error()
end
adc_vref = tonumber(val)

------------------------------------------------------------
-- 温度計算
------------------------------------------------------------
if g_params["SerialNumber"] and g_params["RemoteDeviceName"] and g_params["ActivityLevel"] and g_params["TemperatureLevel"] then
	temperature = (100 * adc_vref * tonumber(g_params["TemperatureLevel"])) / 1024;
	log_msg(string.format("%s IR-count = %s temperature = %2.3g",
            g_params["RemoteDeviceName"],g_params["ActivityLevel"],temperature),file_id)
else
	log_msg("*ERROR* parameter error",file_id);
	error();
end;


------------------------------------------------------------
-- 最後に取得した温度と赤外線カウンタ値を共有データに保存して
-- 他のシステムから簡単に利用できるようにする
-- 
-- キー名  赤外線カウンタ値  "IR_<DeviceName>"
--         温度値            "TP_<DeviceName>"
------------------------------------------------------------
if not set_shared_data("IR_" .. g_params["RemoteDeviceName"],g_params["ActivityLevel"]) then error() end
if not set_shared_data("TP_" .. g_params["RemoteDeviceName"],string.format("%2.3g",temperature)) then error() end


------------------------------------------------------------
-- デバイス名とシリアル番号をデータベースに登録
------------------------------------------------------------
stat = add_permanent_strlist("TDCPDeviceList",g_params["SerialNumber"] .. "," .. g_params["RemoteDeviceName"],true)
if not stat then error() end

------------------------------------------------------------
-- サンプリング値をデータベースに登録
------------------------------------------------------------
key = "SENSOR_IR_" .. g_params["SerialNumber"]
val = tonumber(g_params["ActivityLevel"])

stat = add_stat_data(key,val)
if not stat then error() end

key = "SENSOR_TP_" .. g_params["SerialNumber"]
stat = add_stat_data(key,tostring(temperature))
if not stat then error() end

------------------------------------------------------------
-- ACTIVITIES_CHECK で、IR センサーが
-- 0 以上のカウンタ値を取得したかどうかをチェックするための
-- フラグを設定する
------------------------------------------------------------
if val > 0 then
	if not set_shared_data("RESIDENTS_ACTIVITIES_FLAG","1") then error() end
end


